# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudNaturalLanguageAnalyzeEntitiesOperator(BaseOperator):
    document: "typing.Union[dict, google.cloud.language_v1.types.Document]"
    encoding_type: "typing.Union[google.cloud.language_v1.gapic.enums.EncodingType, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudNaturalLanguageAnalyzeEntitySentimentOperator(BaseOperator):
    document: "typing.Union[dict, google.cloud.language_v1.types.Document]"
    encoding_type: "typing.Union[google.cloud.language_v1.gapic.enums.EncodingType, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudNaturalLanguageAnalyzeSentimentOperator(BaseOperator):
    document: "typing.Union[dict, google.cloud.language_v1.types.Document]"
    encoding_type: "typing.Union[google.cloud.language_v1.gapic.enums.EncodingType, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudNaturalLanguageClassifyTextOperator(BaseOperator):
    document: "typing.Union[dict, google.cloud.language_v1.types.Document]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.models.skipmixin import SkipMixin


class PythonOperator(BaseOperator):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"


class PythonVirtualenvOperator(PythonOperator):
    python_callable: "typing.Callable"
    requirements: "typing.Union[typing.Iterable[str], NoneType]"
    python_version: "typing.Union[str, int, float, NoneType]"
    use_dill: "bool"
    system_site_packages: "bool"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    string_args: "typing.Union[typing.Iterable[str], NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"


class BranchPythonOperator(PythonOperator, SkipMixin):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"


class ShortCircuitOperator(PythonOperator, SkipMixin):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.compute import (
    ComputeEngineBaseOperator,
    ComputeEngineCopyInstanceTemplateOperator,
    ComputeEngineInstanceGroupUpdateManagerTemplateOperator,
    ComputeEngineSetMachineTypeOperator,
    ComputeEngineStartInstanceOperator,
    ComputeEngineStopInstanceOperator,
)


class GceBaseOperator(ComputeEngineBaseOperator):
    pass


class GceInstanceGroupManagerUpdateTemplateOperator(
    ComputeEngineInstanceGroupUpdateManagerTemplateOperator
):
    pass


class GceInstanceStartOperator(ComputeEngineStartInstanceOperator):
    pass


class GceInstanceStopOperator(ComputeEngineStopInstanceOperator):
    pass


class GceInstanceTemplateCopyOperator(ComputeEngineCopyInstanceTemplateOperator):
    pass


class GceSetMachineTypeOperator(ComputeEngineSetMachineTypeOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.functions import (
    CloudFunctionDeleteFunctionOperator,
    CloudFunctionDeployFunctionOperator,
)


class GcfFunctionDeleteOperator(CloudFunctionDeleteFunctionOperator):
    pass


class GcfFunctionDeployOperator(CloudFunctionDeployFunctionOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.sensors.cloud_storage_transfer_service import (
    CloudDataTransferServiceJobStatusSensor,
)


class GCPTransferServiceWaitForJobStatusSensor(CloudDataTransferServiceJobStatusSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.druid.transfers.hive_to_druid import (
    HiveToDruidOperator,
)


class HiveToDruidTransfer(HiveToDruidOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CassandraRecordSensor(BaseSensorOperator):
    table: "str"
    keys: "typing.Dict[str, str]"
    cassandra_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.mysql.transfers.presto_to_mysql import (
    PrestoToMySqlOperator,
)


class PrestoToMySqlTransfer(PrestoToMySqlOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudTasksQueueCreateOperator(BaseOperator):
    location: "str"
    task_queue: "Queue"
    project_id: "typing.Union[str, NoneType]"
    queue_name: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueueDeleteOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueueGetOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueuePauseOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueuePurgeOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueueResumeOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueuesListOperator(BaseOperator):
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    results_filter: "typing.Union[str, NoneType]"
    page_size: "typing.Union[int, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksQueueUpdateOperator(BaseOperator):
    task_queue: "Queue"
    project_id: "typing.Union[str, NoneType]"
    location: "typing.Union[str, NoneType]"
    queue_name: "typing.Union[str, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksTaskCreateOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    task: "typing.Union[typing.Dict, google.cloud.tasks_v2.types.task.Task]"
    project_id: "typing.Union[str, NoneType]"
    task_name: "typing.Union[str, NoneType]"
    response_view: "typing.Optional"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksTaskDeleteOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksTaskGetOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "typing.Union[str, NoneType]"
    response_view: "typing.Optional"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksTaskRunOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "typing.Union[str, NoneType]"
    response_view: "typing.Optional"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudTasksTasksListOperator(BaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "typing.Union[str, NoneType]"
    response_view: "typing.Optional"
    page_size: "typing.Union[int, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ListOperator(BaseOperator):
    bucket: "str"
    prefix: "str"
    delimiter: "str"
    aws_conn_id: "str"
    verify: "typing.Union[str, bool, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.s3_to_redshift import (
    S3ToRedshiftOperator,
)


class S3ToRedshiftTransfer(S3ToRedshiftOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToS3Operator(BaseOperator):
    bucket: "str"
    prefix: "typing.Union[str, NoneType]"
    delimiter: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    dest_aws_conn_id: "str"
    dest_s3_key: "str"
    dest_verify: "typing.Union[str, bool, NoneType]"
    replace: "bool"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    dest_s3_extra_args: "typing.Union[typing.Dict, NoneType]"
    s3_acl_policy: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.text_to_speech import (
    CloudTextToSpeechSynthesizeOperator,
)


class GcpTextToSpeechSynthesizeOperator(CloudTextToSpeechSynthesizeOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.sagemaker_base import (
    SageMakerBaseSensor,
)


class SageMakerTrainingSensor(SageMakerBaseSensor):
    job_name: "_empty"
    print_log: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BigQueryTableExistenceSensor(BaseSensorOperator):
    project_id: "str"
    dataset_id: "str"
    table_id: "str"
    bigquery_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveToDruidOperator(BaseOperator):
    sql: "str"
    druid_datasource: "str"
    ts_dim: "str"
    metric_spec: "typing.Union[typing.List[typing.Any], NoneType]"
    hive_cli_conn_id: "str"
    druid_ingest_conn_id: "str"
    metastore_conn_id: "str"
    hadoop_dependency_coordinates: "typing.Union[typing.List[str], NoneType]"
    intervals: "typing.Union[typing.List[typing.Any], NoneType]"
    num_shards: "float"
    target_partition_size: "int"
    query_granularity: "str"
    segment_granularity: "str"
    hive_tblproperties: "typing.Union[typing.Dict[typing.Any, typing.Any], NoneType]"
    job_properties: "typing.Union[typing.Dict[typing.Any, typing.Any], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class JiraOperator(BaseOperator):
    jira_method: "str"
    jira_conn_id: "str"
    jira_method_args: "typing.Union[dict, NoneType]"
    result_processor: "typing.Union[typing.Callable, NoneType]"
    get_jira_resource_method: "typing.Union[typing.Callable, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.sensors.gcs import (
    GCSObjectExistenceSensor,
    GCSObjectsWithPrefixExistenceSensor,
    GCSObjectUpdateSensor,
    GCSUploadSessionCompleteSensor,
)


class GoogleCloudStorageObjectSensor(GCSObjectExistenceSensor):
    pass


class GoogleCloudStorageObjectUpdatedSensor(GCSObjectUpdateSensor):
    pass


class GoogleCloudStoragePrefixSensor(GCSObjectsWithPrefixExistenceSensor):
    pass


class GoogleCloudStorageUploadSessionCompleteSensor(GCSUploadSessionCompleteSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.operators.python import PythonVirtualenvOperator


class _PythonVirtualenvDecoratedOperator(DecoratedOperator, PythonVirtualenvOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.kubernetes_pod import (
    KubernetesPodOperator,
)


class GKECreateClusterOperator(BaseOperator):
    location: "str"
    body: "typing.Union[typing.Dict, google.cloud.container_v1.types.Cluster, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GKEDeleteClusterOperator(BaseOperator):
    name: "str"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GKEStartPodOperator(KubernetesPodOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DecoratedOperator(BaseOperator):
    python_callable: "typing.Callable"
    task_id: "str"
    op_args: "typing.Tuple[typing.Any]"
    op_kwargs: "typing.Dict[str, typing.Any]"
    multiple_outputs: "bool"
    kwargs_to_upstream: "dict"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dataproc import (
    DataprocCreateClusterOperator,
    DataprocDeleteClusterOperator,
    DataprocInstantiateInlineWorkflowTemplateOperator,
    DataprocInstantiateWorkflowTemplateOperator,
    DataprocJobBaseOperator,
    DataprocScaleClusterOperator,
    DataprocSubmitHadoopJobOperator,
    DataprocSubmitHiveJobOperator,
    DataprocSubmitPigJobOperator,
    DataprocSubmitPySparkJobOperator,
    DataprocSubmitSparkJobOperator,
    DataprocSubmitSparkSqlJobOperator,
)


class DataprocClusterCreateOperator(DataprocCreateClusterOperator):
    pass


class DataprocClusterDeleteOperator(DataprocDeleteClusterOperator):
    pass


class DataprocClusterScaleOperator(DataprocScaleClusterOperator):
    pass


class DataProcHadoopOperator(DataprocSubmitHadoopJobOperator):
    pass


class DataProcHiveOperator(DataprocSubmitHiveJobOperator):
    pass


class DataProcJobBaseOperator(DataprocJobBaseOperator):
    pass


class DataProcPigOperator(DataprocSubmitPigJobOperator):
    pass


class DataProcPySparkOperator(DataprocSubmitPySparkJobOperator):
    pass


class DataProcSparkOperator(DataprocSubmitSparkJobOperator):
    pass


class DataProcSparkSqlOperator(DataprocSubmitSparkSqlJobOperator):
    pass


class DataprocWorkflowTemplateInstantiateInlineOperator(
    DataprocInstantiateInlineWorkflowTemplateOperator
):
    pass


class DataprocWorkflowTemplateInstantiateOperator(
    DataprocInstantiateWorkflowTemplateOperator
):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.hive_to_mysql import (
    HiveToMySqlOperator,
)


class HiveToMySqlTransfer(HiveToMySqlOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToMySqlOperator(BaseOperator):
    dataset_table: "str"
    mysql_table: "str"
    selected_fields: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    mysql_conn_id: "str"
    database: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    replace: "bool"
    batch_size: "int"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SparkSubmitOperator(BaseOperator):
    application: "str"
    conf: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    conn_id: "str"
    files: "typing.Union[str, NoneType]"
    py_files: "typing.Union[str, NoneType]"
    archives: "typing.Union[str, NoneType]"
    driver_class_path: "typing.Union[str, NoneType]"
    jars: "typing.Union[str, NoneType]"
    java_class: "typing.Union[str, NoneType]"
    packages: "typing.Union[str, NoneType]"
    exclude_packages: "typing.Union[str, NoneType]"
    repositories: "typing.Union[str, NoneType]"
    total_executor_cores: "typing.Union[int, NoneType]"
    executor_cores: "typing.Union[int, NoneType]"
    executor_memory: "typing.Union[str, NoneType]"
    driver_memory: "typing.Union[str, NoneType]"
    keytab: "typing.Union[str, NoneType]"
    principal: "typing.Union[str, NoneType]"
    proxy_user: "typing.Union[str, NoneType]"
    name: "str"
    num_executors: "typing.Union[int, NoneType]"
    status_poll_interval: "int"
    application_args: "typing.Union[typing.List[typing.Any], NoneType]"
    env_vars: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    verbose: "bool"
    spark_binary: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.google_api_to_s3 import (
    GoogleApiToS3Operator,
)


class GoogleApiToS3Transfer(GoogleApiToS3Operator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureCosmosInsertDocumentOperator(BaseOperator):
    database_name: "str"
    collection_name: "str"
    document: "dict"
    azure_cosmos_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class MsSqlToHiveOperator(BaseOperator):
    sql: "str"
    hive_table: "str"
    create: "bool"
    recreate: "bool"
    partition: "typing.Union[typing.Dict, NoneType]"
    delimiter: "str"
    mssql_conn_id: "str"
    hive_cli_conn_id: "str"
    tblproperties: "typing.Union[typing.Dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.vision import (
    CloudVisionCreateProductOperator,
    CloudVisionCreateProductSetOperator,
    CloudVisionCreateReferenceImageOperator,
    CloudVisionDeleteProductOperator,
    CloudVisionDeleteProductSetOperator,
    CloudVisionGetProductOperator,
    CloudVisionGetProductSetOperator,
    CloudVisionImageAnnotateOperator,
    CloudVisionTextDetectOperator,
    CloudVisionUpdateProductOperator,
    CloudVisionUpdateProductSetOperator,
)


class CloudVisionAnnotateImageOperator(CloudVisionImageAnnotateOperator):
    pass


class CloudVisionDetectDocumentTextOperator(CloudVisionTextDetectOperator):
    pass


class CloudVisionProductCreateOperator(CloudVisionCreateProductOperator):
    pass


class CloudVisionProductDeleteOperator(CloudVisionDeleteProductOperator):
    pass


class CloudVisionProductGetOperator(CloudVisionGetProductOperator):
    pass


class CloudVisionProductSetCreateOperator(CloudVisionCreateProductSetOperator):
    pass


class CloudVisionProductSetDeleteOperator(CloudVisionDeleteProductSetOperator):
    pass


class CloudVisionProductSetGetOperator(CloudVisionGetProductSetOperator):
    pass


class CloudVisionProductSetUpdateOperator(CloudVisionUpdateProductSetOperator):
    pass


class CloudVisionProductUpdateOperator(CloudVisionUpdateProductOperator):
    pass


class CloudVisionReferenceImageCreateOperator(CloudVisionCreateReferenceImageOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.microsoft.azure.operators.adls_list import (
    AzureDataLakeStorageListOperator,
)


class ADLSToGCSOperator(AzureDataLakeStorageListOperator):
    src_adls: "str"
    dest_gcs: "str"
    azure_data_lake_conn_id: "str"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    replace: "bool"
    gzip: "bool"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.sagemaker_base import (
    SageMakerBaseOperator,
)


class SageMakerTransformOperator(SageMakerBaseOperator):
    config: "dict"
    wait_for_completion: "bool"
    check_interval: "int"
    max_ingestion_time: "typing.Union[int, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveOperator(BaseOperator):
    hql: "str"
    hive_cli_conn_id: "str"
    schema: "str"
    hiveconfs: "typing.Union[typing.Dict[typing.Any, typing.Any], NoneType]"
    hiveconf_jinja_translate: "bool"
    script_begin_tag: "typing.Union[str, NoneType]"
    run_as_owner: "bool"
    mapred_queue: "typing.Union[str, NoneType]"
    mapred_queue_priority: "typing.Union[str, NoneType]"
    mapred_job_name: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.natural_language import (
    CloudNaturalLanguageAnalyzeEntitiesOperator,
    CloudNaturalLanguageAnalyzeEntitySentimentOperator,
    CloudNaturalLanguageAnalyzeSentimentOperator,
    CloudNaturalLanguageClassifyTextOperator,
)


class CloudLanguageAnalyzeEntitiesOperator(CloudNaturalLanguageAnalyzeEntitiesOperator):
    pass


class CloudLanguageAnalyzeEntitySentimentOperator(
    CloudNaturalLanguageAnalyzeEntitySentimentOperator
):
    pass


class CloudLanguageAnalyzeSentimentOperator(
    CloudNaturalLanguageAnalyzeSentimentOperator
):
    pass


class CloudLanguageClassifyTextOperator(CloudNaturalLanguageClassifyTextOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DingdingOperator(BaseOperator):
    dingding_conn_id: "str"
    message_type: "str"
    message: "typing.Union[str, dict, NoneType]"
    at_mobiles: "typing.Union[typing.List[str], NoneType]"
    at_all: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AthenaSensor(BaseSensorOperator):
    query_execution_id: "str"
    max_retries: "typing.Union[int, NoneType]"
    aws_conn_id: "str"
    sleep_time: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class TriggerDagRunOperator(BaseOperator):
    trigger_dag_id: "str"
    conf: "typing.Union[typing.Dict, NoneType]"
    execution_date: "typing.Union[str, datetime.datetime, NoneType]"
    reset_dag_run: "bool"
    wait_for_completion: "bool"
    poke_interval: "int"
    allowed_states: "typing.Union[typing.List, NoneType]"
    failed_states: "typing.Union[typing.List, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class VerticaOperator(BaseOperator):
    sql: "typing.Union[str, typing.List[str]]"
    vertica_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureDataLakeStorageListOperator(BaseOperator):
    path: "str"
    azure_data_lake_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.cassandra_to_gcs import (
    CassandraToGCSOperator,
)


class CassandraToGoogleCloudStorageOperator(CassandraToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ImapAttachmentToS3Operator(BaseOperator):
    imap_attachment_name: "str"
    s3_key: "str"
    imap_check_regex: "bool"
    imap_mail_folder: "str"
    imap_mail_filter: "str"
    s3_overwrite: "bool"
    imap_conn_id: "str"
    s3_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmrAddStepsOperator(BaseOperator):
    job_flow_id: "typing.Union[str, NoneType]"
    job_flow_name: "typing.Union[str, NoneType]"
    cluster_states: "typing.Union[typing.List[str], NoneType]"
    aws_conn_id: "str"
    steps: "typing.Union[typing.List[dict], str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SlackAPIOperator(BaseOperator):
    slack_conn_id: "typing.Union[str, NoneType]"
    token: "typing.Union[str, NoneType]"
    method: "typing.Union[str, NoneType]"
    api_params: "typing.Union[typing.Dict, NoneType]"


class SlackAPIPostOperator(SlackAPIOperator):
    channel: "str"
    username: "str"
    text: "str"
    icon_url: "str"
    attachments: "typing.Union[typing.List, NoneType]"
    blocks: "typing.Union[typing.List, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AwsRedshiftClusterSensor(BaseSensorOperator):
    cluster_identifier: "str"
    target_status: "str"
    aws_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudVideoIntelligenceDetectVideoExplicitContentOperator(BaseOperator):
    input_uri: "str"
    output_uri: "typing.Union[str, NoneType]"
    input_content: "typing.Union[bytes, NoneType]"
    video_context: "typing.Union[typing.Dict, google.cloud.videointelligence_v1.types.VideoContext]"
    location: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVideoIntelligenceDetectVideoLabelsOperator(BaseOperator):
    input_uri: "str"
    input_content: "typing.Union[bytes, NoneType]"
    output_uri: "typing.Union[str, NoneType]"
    video_context: "typing.Union[typing.Dict, google.cloud.videointelligence_v1.types.VideoContext]"
    location: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVideoIntelligenceDetectVideoShotsOperator(BaseOperator):
    input_uri: "str"
    output_uri: "typing.Union[str, NoneType]"
    input_content: "typing.Union[bytes, NoneType]"
    video_context: "typing.Union[typing.Dict, google.cloud.videointelligence_v1.types.VideoContext]"
    location: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.sagemaker_base import (
    SageMakerBaseOperator,
)


class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
    config: "dict"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.gcs import (
    GCSDeleteObjectsOperator,
)


class GoogleCloudStorageDeleteOperator(GCSDeleteObjectsOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HdfsSensor(BaseSensorOperator):
    filepath: "str"
    hdfs_conn_id: "str"
    ignored_ext: "typing.Union[typing.List[str], NoneType]"
    ignore_copying: "bool"
    file_size: "typing.Union[int, NoneType]"
    hook: "typing.Type[airflow.providers.apache.hdfs.hooks.hdfs.HDFSHook]"


class HdfsFolderSensor(HdfsSensor):
    be_empty: "bool"


class HdfsRegexSensor(HdfsSensor):
    regex: "typing.Pattern[str]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToBigQueryOperator(BaseOperator):
    source_project_dataset_tables: "typing.Union[typing.List[str], str]"
    destination_project_dataset_table: "str"
    write_disposition: "str"
    create_disposition: "str"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    encryption_configuration: "typing.Union[typing.Dict, NoneType]"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.branch import BaseBranchOperator


class BranchDayOfWeekOperator(BaseBranchOperator):
    follow_task_ids_if_true: "typing.Union[str, typing.Iterable[str]]"
    follow_task_ids_if_false: "typing.Union[str, typing.Iterable[str]]"
    week_day: "typing.Union[str, typing.Iterable[str]]"
    use_task_execution_day: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class S3PrefixSensor(BaseSensorOperator):
    bucket_name: "str"
    prefix: "str"
    delimiter: "str"
    aws_conn_id: "str"
    verify: "typing.Union[bool, str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GrpcOperator(BaseOperator):
    stub_class: "typing.Callable"
    call_func: "str"
    grpc_conn_id: "str"
    data: "typing.Union[dict, NoneType]"
    interceptors: "typing.Union[typing.List[typing.Callable], NoneType]"
    custom_connection_func: "typing.Union[typing.Callable, NoneType]"
    streaming: "bool"
    response_callback: "typing.Union[typing.Callable, NoneType]"
    log_response: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.bigquery import (
    BigQueryDeleteTableOperator,
)


class BigQueryTableDeleteOperator(BigQueryDeleteTableOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.postgres_to_gcs import (
    PostgresToGCSOperator,
)


class PostgresToGoogleCloudStorageOperator(PostgresToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CassandraToGCSOperator(BaseOperator):
    cql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "typing.Union[str, NoneType]"
    approx_max_file_size_bytes: "int"
    gzip: "bool"
    cassandra_conn_id: "str"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SFTPToS3Operator(BaseOperator):
    s3_bucket: "str"
    s3_key: "str"
    sftp_path: "str"
    sftp_conn_id: "str"
    s3_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpsgenieAlertOperator(BaseOperator):
    message: "str"
    opsgenie_conn_id: "str"
    alias: "typing.Union[str, NoneType]"
    description: "typing.Union[str, NoneType]"
    responders: "typing.Union[typing.List[dict], NoneType]"
    visible_to: "typing.Union[typing.List[dict], NoneType]"
    actions: "typing.Union[typing.List[str], NoneType]"
    tags: "typing.Union[typing.List[str], NoneType]"
    details: "typing.Union[dict, NoneType]"
    entity: "typing.Union[str, NoneType]"
    source: "typing.Union[str, NoneType]"
    priority: "typing.Union[str, NoneType]"
    user: "typing.Union[str, NoneType]"
    note: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SQSSensor(BaseSensorOperator):
    sqs_queue: "_empty"
    aws_conn_id: "str"
    max_messages: "int"
    wait_time_seconds: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudSQLBaseOperator(BaseOperator):
    instance: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLCreateInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLCreateInstanceOperator(CloudSQLBaseOperator):
    body: "dict"
    instance: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLDeleteInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    database: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLDeleteInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLExecuteQueryOperator(BaseOperator):
    sql: "typing.Union[typing.List[str], str]"
    autocommit: "bool"
    parameters: "typing.Union[typing.Dict, typing.Iterable, NoneType]"
    gcp_conn_id: "str"
    gcp_cloudsql_conn_id: "str"


class CloudSQLExportInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLImportInstanceOperator(CloudSQLBaseOperator):
    instance: "str"
    body: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLInstancePatchOperator(CloudSQLBaseOperator):
    body: "dict"
    instance: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudSQLPatchInstanceDatabaseOperator(CloudSQLBaseOperator):
    instance: "str"
    database: "str"
    body: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class PubSubPullSensor(BaseSensorOperator):
    project_id: "str"
    subscription: "str"
    max_messages: "int"
    return_immediately: "bool"
    ack_messages: "bool"
    gcp_conn_id: "str"
    messages_callback: "typing.Union[typing.Callable[[typing.List[google.cloud.pubsub_v1.types.ReceivedMessage], typing.Dict[str, typing.Any]], typing.Any], NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    project: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigtableValidationMixin:
    pass


class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
    instance_id: "str"
    main_cluster_id: "str"
    main_cluster_zone: "str"
    project_id: "typing.Union[str, NoneType]"
    replica_clusters: "typing.Union[typing.List[typing.Dict[str, str]], NoneType]"
    replica_cluster_id: "typing.Union[str, NoneType]"
    replica_cluster_zone: "typing.Union[str, NoneType]"
    instance_display_name: "typing.Union[str, NoneType]"
    instance_type: "typing.Union[google.cloud.bigtable_admin_v2.gapic.enums.Instance.Type, NoneType]"
    instance_labels: "typing.Union[typing.Dict, NoneType]"
    cluster_nodes: "typing.Union[int, NoneType]"
    cluster_storage_type: "typing.Union[google.cloud.bigtable_admin_v2.gapic.enums.StorageType, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
    instance_id: "str"
    table_id: "str"
    project_id: "typing.Union[str, NoneType]"
    initial_split_keys: "typing.Union[typing.List, NoneType]"
    column_families: "typing.Union[typing.Dict[str, google.cloud.bigtable.column_family.GarbageCollectionRule], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
    instance_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
    instance_id: "str"
    table_id: "str"
    project_id: "typing.Union[str, NoneType]"
    app_profile_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
    instance_id: "str"
    cluster_id: "str"
    nodes: "int"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class MySQLToGCSOperator(BaseSQLToGCSOperator):
    mysql_conn_id: "_empty"
    ensure_utc: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class JiraSensor(BaseSensorOperator):
    method_name: "str"
    jira_conn_id: "str"
    method_params: "typing.Union[dict, NoneType]"
    result_processor: "typing.Union[typing.Callable, NoneType]"


class JiraTicketSensor(JiraSensor):
    jira_conn_id: "str"
    ticket_id: "typing.Union[str, NoneType]"
    field: "typing.Union[str, NoneType]"
    expected_value: "typing.Union[str, NoneType]"
    field_checker_func: "typing.Union[typing.Callable, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SubDagOperator(BaseSensorOperator):
    subdag: "DAG"
    session: "typing.Union[sqlalchemy.orm.session.Session, NoneType]"
    conf: "typing.Union[typing.Dict, NoneType]"
    propagate_skipped_state: "typing.Union[airflow.operators.subdag.SkippedStatePropagationOptions, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.spark.operators.spark_submit import (
    SparkSubmitOperator,
)


class SparkJDBCOperator(SparkSubmitOperator):
    spark_app_name: "str"
    spark_conn_id: "str"
    spark_conf: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    spark_py_files: "typing.Union[str, NoneType]"
    spark_files: "typing.Union[str, NoneType]"
    spark_jars: "typing.Union[str, NoneType]"
    num_executors: "typing.Union[int, NoneType]"
    executor_cores: "typing.Union[int, NoneType]"
    executor_memory: "typing.Union[str, NoneType]"
    driver_memory: "typing.Union[str, NoneType]"
    verbose: "bool"
    principal: "typing.Union[str, NoneType]"
    keytab: "typing.Union[str, NoneType]"
    cmd_type: "str"
    jdbc_table: "typing.Union[str, NoneType]"
    jdbc_conn_id: "str"
    jdbc_driver: "typing.Union[str, NoneType]"
    metastore_table: "typing.Union[str, NoneType]"
    jdbc_truncate: "bool"
    save_mode: "typing.Union[str, NoneType]"
    save_format: "typing.Union[str, NoneType]"
    batch_size: "typing.Union[int, NoneType]"
    fetch_size: "typing.Union[int, NoneType]"
    num_partitions: "typing.Union[int, NoneType]"
    partition_column: "typing.Union[str, NoneType]"
    lower_bound: "typing.Union[str, NoneType]"
    upper_bound: "typing.Union[str, NoneType]"
    create_table_column_types: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DockerOperator(BaseOperator):
    image: "str"
    api_version: "typing.Union[str, NoneType]"
    command: "typing.Union[str, typing.List[str], NoneType]"
    container_name: "typing.Union[str, NoneType]"
    cpus: "float"
    docker_url: "str"
    environment: "typing.Union[typing.Dict, NoneType]"
    private_environment: "typing.Union[typing.Dict, NoneType]"
    force_pull: "bool"
    mem_limit: "typing.Union[float, str, NoneType]"
    host_tmp_dir: "typing.Union[str, NoneType]"
    network_mode: "typing.Union[str, NoneType]"
    tls_ca_cert: "typing.Union[str, NoneType]"
    tls_client_cert: "typing.Union[str, NoneType]"
    tls_client_key: "typing.Union[str, NoneType]"
    tls_hostname: "typing.Union[str, bool, NoneType]"
    tls_ssl_version: "typing.Union[str, NoneType]"
    tmp_dir: "str"
    user: "typing.Union[str, int, NoneType]"
    mounts: "typing.Union[typing.List[docker.types.services.Mount], NoneType]"
    entrypoint: "typing.Union[str, typing.List[str], NoneType]"
    working_dir: "typing.Union[str, NoneType]"
    xcom_all: "bool"
    docker_conn_id: "typing.Union[str, NoneType]"
    dns: "typing.Union[typing.List[str], NoneType]"
    dns_search: "typing.Union[typing.List[str], NoneType]"
    auto_remove: "bool"
    shm_size: "typing.Union[int, NoneType]"
    tty: "bool"
    privileged: "bool"
    cap_add: "typing.Union[typing.Iterable[str], NoneType]"
    extra_hosts: "typing.Union[typing.Dict[str, str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SqoopOperator(BaseOperator):
    conn_id: "str"
    cmd_type: "str"
    table: "typing.Union[str, NoneType]"
    query: "typing.Union[str, NoneType]"
    target_dir: "typing.Union[str, NoneType]"
    append: "bool"
    file_type: "str"
    columns: "typing.Union[str, NoneType]"
    num_mappers: "typing.Union[int, NoneType]"
    split_by: "typing.Union[str, NoneType]"
    where: "typing.Union[str, NoneType]"
    export_dir: "typing.Union[str, NoneType]"
    input_null_string: "typing.Union[str, NoneType]"
    input_null_non_string: "typing.Union[str, NoneType]"
    staging_table: "typing.Union[str, NoneType]"
    clear_staging_table: "bool"
    enclosed_by: "typing.Union[str, NoneType]"
    escaped_by: "typing.Union[str, NoneType]"
    input_fields_terminated_by: "typing.Union[str, NoneType]"
    input_lines_terminated_by: "typing.Union[str, NoneType]"
    input_optionally_enclosed_by: "typing.Union[str, NoneType]"
    batch: "bool"
    direct: "bool"
    driver: "typing.Union[typing.Any, NoneType]"
    verbose: "bool"
    relaxed_isolation: "bool"
    properties: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    hcatalog_database: "typing.Union[str, NoneType]"
    hcatalog_table: "typing.Union[str, NoneType]"
    create_hcatalog_table: "bool"
    extra_import_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    extra_export_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hdfs.sensors.hdfs import (
    HdfsFolderSensor,
    HdfsRegexSensor,
)


class HdfsSensorFolder(HdfsFolderSensor):
    pass


class HdfsSensorRegex(HdfsRegexSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class KubernetesPodOperator(BaseOperator):
    namespace: "typing.Union[str, NoneType]"
    image: "typing.Union[str, NoneType]"
    name: "typing.Union[str, NoneType]"
    cmds: "typing.Union[typing.List[str], NoneType]"
    arguments: "typing.Union[typing.List[str], NoneType]"
    ports: "typing.Union[typing.List[kubernetes.client.models.v1_container_port.V1ContainerPort], NoneType]"
    volume_mounts: "typing.Union[typing.List[kubernetes.client.models.v1_volume_mount.V1VolumeMount], NoneType]"
    volumes: "typing.Union[typing.List[kubernetes.client.models.v1_volume.V1Volume], NoneType]"
    env_vars: "typing.Union[typing.List[kubernetes.client.models.v1_env_var.V1EnvVar], NoneType]"
    env_from: "typing.Union[typing.List[kubernetes.client.models.v1_env_from_source.V1EnvFromSource], NoneType]"
    secrets: "typing.Union[typing.List[airflow.kubernetes.secret.Secret], NoneType]"
    in_cluster: "typing.Union[bool, NoneType]"
    cluster_context: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    reattach_on_restart: "bool"
    startup_timeout_seconds: "int"
    get_logs: "bool"
    image_pull_policy: "typing.Union[str, NoneType]"
    annotations: "typing.Union[typing.Dict, NoneType]"
    resources: "typing.Union[kubernetes.client.models.v1_resource_requirements.V1ResourceRequirements, NoneType]"
    affinity: "typing.Union[kubernetes.client.models.v1_affinity.V1Affinity, NoneType]"
    config_file: "typing.Union[str, NoneType]"
    node_selectors: "typing.Union[dict, NoneType]"
    node_selector: "typing.Union[dict, NoneType]"
    image_pull_secrets: "typing.Union[typing.List[kubernetes.client.models.v1_local_object_reference.V1LocalObjectReference], NoneType]"
    service_account_name: "typing.Union[str, NoneType]"
    is_delete_operator_pod: "bool"
    hostnetwork: "bool"
    tolerations: "typing.Union[typing.List[kubernetes.client.models.v1_toleration.V1Toleration], NoneType]"
    security_context: "typing.Union[typing.Dict, NoneType]"
    dnspolicy: "typing.Union[str, NoneType]"
    schedulername: "typing.Union[str, NoneType]"
    full_pod_spec: "typing.Union[kubernetes.client.models.v1_pod.V1Pod, NoneType]"
    init_containers: "typing.Union[typing.List[kubernetes.client.models.v1_container.V1Container], NoneType]"
    log_events_on_failure: "bool"
    do_xcom_push: "bool"
    pod_template_file: "typing.Union[str, NoneType]"
    priority_class_name: "typing.Union[str, NoneType]"
    pod_runtime_info_envs: "typing.List[airflow.providers.cncf.kubernetes.backcompat.pod_runtime_info_env.PodRuntimeInfoEnv]"
    termination_grace_period: "typing.Union[int, NoneType]"
    configmaps: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveToMySqlOperator(BaseOperator):
    sql: "str"
    mysql_table: "str"
    hiveserver2_conn_id: "str"
    mysql_conn_id: "str"
    mysql_preoperator: "typing.Union[str, NoneType]"
    mysql_postoperator: "typing.Union[str, NoneType]"
    bulk_load: "bool"
    hive_conf: "typing.Union[typing.Dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.sensors.bigquery import (
    BigQueryTableExistenceSensor,
)


class BigQueryTableSensor(BigQueryTableExistenceSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class QuboleSensor(BaseSensorOperator):
    data: "_empty"
    qubole_conn_id: "str"


class QuboleFileSensor(QuboleSensor):
    pass


class QubolePartitionSensor(QuboleSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToGCSOperator(BaseOperator):
    source_project_dataset_table: "str"
    destination_cloud_storage_uris: "typing.List[str]"
    compression: "str"
    export_format: "str"
    field_delimiter: "str"
    print_header: "bool"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmrCreateJobFlowOperator(BaseOperator):
    aws_conn_id: "str"
    emr_conn_id: "str"
    job_flow_overrides: "typing.Union[str, typing.Dict[str, typing.Any], NoneType]"
    region_name: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.http.operators.http import SimpleHttpOperator


class SlackWebhookOperator(SimpleHttpOperator):
    http_conn_id: "str"
    webhook_token: "typing.Union[str, NoneType]"
    message: "str"
    attachments: "typing.Union[list, NoneType]"
    blocks: "typing.Union[list, NoneType]"
    channel: "typing.Union[str, NoneType]"
    username: "typing.Union[str, NoneType]"
    icon_emoji: "typing.Union[str, NoneType]"
    icon_url: "typing.Union[str, NoneType]"
    link_names: "bool"
    proxy: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dlp import (
    CloudDLPDeleteDLPJobOperator,
    CloudDLPGetDLPJobOperator,
    CloudDLPGetDLPJobTriggerOperator,
    CloudDLPListDLPJobsOperator,
)


class CloudDLPDeleteDlpJobOperator(CloudDLPDeleteDLPJobOperator):
    pass


class CloudDLPGetDlpJobOperator(CloudDLPGetDLPJobOperator):
    pass


class CloudDLPGetJobTripperOperator(CloudDLPGetDLPJobTriggerOperator):
    pass


class CloudDLPListDlpJobsOperator(CloudDLPListDLPJobsOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SimpleHttpOperator(BaseOperator):
    endpoint: "typing.Union[str, NoneType]"
    method: "str"
    data: "typing.Any"
    headers: "typing.Union[typing.Dict[str, str], NoneType]"
    response_check: "typing.Union[typing.Callable[..., bool], NoneType]"
    response_filter: "typing.Union[typing.Callable[..., typing.Any], NoneType]"
    extra_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    http_conn_id: "str"
    log_response: "bool"
    auth_type: "typing.Type[requests.auth.AuthBase]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PigOperator(BaseOperator):
    pig: "str"
    pig_cli_conn_id: "str"
    pigparams_jinja_translate: "bool"
    pig_opts: "typing.Union[str, NoneType]"



import ast
import json
from typing import Any, Dict, List, Optional, Tuple, Type

import astor
import attr
import cattr

from airfly.utils import blacking, isorting

immutable = attr.s(auto_attribs=True, slots=True, frozen=True, kw_only=True)


class Serializable:
    @classmethod
    def to_dict(self, recurse=True, **kwargs):
        return attr.asdict(self, recurse=recurse, **kwargs)

    @classmethod
    def from_dict(cls, data: Dict):
        return cattr.structure_attrs_fromdict(data, cls)

    @classmethod
    def from_json(cls, json_str: str):
        return cls.from_dict(json.loads(json_str))

    def to_json(self, ensure_ascii=False, **kwargs):
        return json.dumps(self.to_dict(), ensure_ascii=ensure_ascii, **kwargs)

    def evolve(self, **kwargs):
        return attr.evolve(self, **kwargs)

    def mutate_from_other(self, other: "Serializable", excludes=[]):
        valid_fields = [
            f1.name
            for f1 in attr.fields(other.__class__)
            if (getattr(other, f1.name, None) is not None)
            and (f1.name not in excludes)
            and (f1.name in [f2.name for f2 in attr.fields(self.__class__)])
        ]

        data = other.to_dict(filter=lambda att, value: att.name in valid_fields)

        return self.evolve(**data)


class _AST(Serializable):
    def __repr__(self):
        return str(self)

    def __str__(self):
        return type(self).__name__


@immutable
class AST(_AST):
    @classmethod
    def get_ast_type(cls) -> Type[ast.AST]:
        return getattr(ast, cls.__name__)

    @property
    def ast(self) -> ast.AST:
        cls = type(self)
        fields: Tuple[attr.Attribute, ...] = (
            attr.fields(cls) if attr.has(cls) else tuple()
        )

        ast_type = self.get_ast_type()

        ast_fields: Tuple[str, ...] = ast_type._fields

        kwargs = {}

        for fd in fields:
            _name = fd.name
            if _name in ast_fields:

                value = getattr(self, _name)

                if isinstance(value, List):
                    value = [v.ast if isinstance(v, _AST) else v for v in value]
                else:
                    value = value.ast if isinstance(value, _AST) else value

                kwargs.update({_name: value})

        return ast_type(**kwargs)

    def render(self) -> str:

        return astor.to_source(self.ast)

    def dump(self, filepath: str, formatted: bool = False) -> Any:

        code = self.render()

        if formatted:
            code = blacking(isorting(code))

        with open(filepath, "w") as f:
            f.write(code)


@immutable
class TypeIgnore(AST):
    lineno: int
    tag: str


@immutable
class alias(AST):
    name: str
    asname: Optional[str] = None


class expr_context(AST):
    pass


class Load(expr_context):
    pass


class Store(expr_context):
    pass


class Del(expr_context):
    pass


@immutable
class arg(AST):
    arg: str
    annotation: Optional[str] = None
    type_comment: Optional[str] = None


class expr(AST):
    pass


@immutable
class Name(expr):
    id: str
    ctx: expr_context = Load()


@immutable
class keyword(AST):
    arg: str
    value: expr


class slice(AST):
    pass


@immutable
class Index(slice):
    value: expr


@immutable
class Call(expr):
    func: expr
    args: List[expr] = attr.ib(factory=list)
    keywords: List[keyword] = attr.ib(factory=list)


@immutable
class arguments(AST):

    posonlyargs: List[arg] = attr.ib(factory=list)
    args: List[arg] = attr.ib(factory=list)
    vararg: Optional[arg] = None
    kwonlyargs: List[arg] = attr.ib(factory=list)
    kw_defaults: List[expr] = attr.ib(factory=list)
    kwarg: Optional[arg] = None
    defaults: List[expr] = attr.ib(factory=list)


@immutable
class Constant(expr):
    value: str
    kind: Optional[str] = None


@immutable
class Subscript(expr):
    value: expr
    slice: expr
    ctx: expr_context = Load()


class stmt(AST):
    pass


@immutable
class Expr(stmt):
    value: expr


@immutable
class Comment(stmt):

    body: str

    @classmethod
    def get_ast_type(cls) -> Type[ast.AST]:
        return ast.Expr

    @property
    def ast(self) -> ast.AST:

        body: str = self.body.strip()

        cmt = body if body.startswith("#") else f"# {body}"

        return ast.Expr(value=ast.Name(id=cmt))


@immutable
class Assign(stmt):
    targets: List[expr]
    value: expr
    type_comment: Optional[str] = None


class Pass(stmt):
    pass


@immutable
class FunctionDef(stmt):
    name: str
    args: arguments
    body: List[stmt] = attr.ib(default=[Pass()])
    decorator_list: List[expr] = attr.ib(factory=list)
    returns: Optional[expr] = None
    type_comment: Optional[str] = None


@immutable
class withitem(AST):
    context_expr: expr
    optional_vars: Optional[expr] = None


@immutable
class With(stmt):
    items: List[withitem]
    body: List[stmt] = attr.ib(default=[Pass()])
    type_comment: Optional[str] = None


@immutable
class Module(AST):
    body: List[stmt] = attr.ib(factory=list)
    type_ignores: List[TypeIgnore] = attr.ib(factory=list)


@immutable
class ClassDef(stmt):
    name: str
    bases: List[expr] = attr.ib(factory=list)
    keywords: List[keyword] = attr.ib(factory=list)
    body: List[stmt] = attr.ib(default=[Pass()])
    decorator_list: List[expr] = attr.ib(factory=list)


@immutable
class AnnAssign(stmt):
    target: expr
    annotation: expr
    value: Optional[expr] = None
    simple: int = 1


@immutable
class Code(Serializable):

    modname: str
    module: Module = Module(body=[])


@immutable
class Import(stmt):
    names: List[alias] = attr.ib(factory=list)


@immutable
class ImportFrom(stmt):
    module: str
    names: List[alias] = attr.ib(factory=list)
    level: int = 0


class operator(AST):
    pass


class RShift(operator):
    pass


@immutable
class BinOp(expr):
    left: expr
    op: operator
    right: expr



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class WasbBlobSensor(BaseSensorOperator):
    container_name: "str"
    blob_name: "str"
    wasb_conn_id: "str"
    check_options: "typing.Union[dict, NoneType]"


class WasbPrefixSensor(BaseSensorOperator):
    container_name: "str"
    prefix: "str"
    wasb_conn_id: "str"
    check_options: "typing.Union[dict, NoneType]"



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['airfly',
 'airfly._vendor',
 'airfly._vendor.airflow',
 'airfly._vendor.airflow.contrib',
 'airfly._vendor.airflow.contrib.operators',
 'airfly._vendor.airflow.contrib.sensors',
 'airfly._vendor.airflow.decorators',
 'airfly._vendor.airflow.example_dags',
 'airfly._vendor.airflow.models',
 'airfly._vendor.airflow.operators',
 'airfly._vendor.airflow.providers',
 'airfly._vendor.airflow.providers.amazon',
 'airfly._vendor.airflow.providers.amazon.aws',
 'airfly._vendor.airflow.providers.amazon.aws.operators',
 'airfly._vendor.airflow.providers.amazon.aws.sensors',
 'airfly._vendor.airflow.providers.amazon.aws.transfers',
 'airfly._vendor.airflow.providers.apache',
 'airfly._vendor.airflow.providers.apache.cassandra',
 'airfly._vendor.airflow.providers.apache.cassandra.sensors',
 'airfly._vendor.airflow.providers.apache.druid',
 'airfly._vendor.airflow.providers.apache.druid.operators',
 'airfly._vendor.airflow.providers.apache.druid.transfers',
 'airfly._vendor.airflow.providers.apache.hdfs',
 'airfly._vendor.airflow.providers.apache.hdfs.sensors',
 'airfly._vendor.airflow.providers.apache.hive',
 'airfly._vendor.airflow.providers.apache.hive.operators',
 'airfly._vendor.airflow.providers.apache.hive.sensors',
 'airfly._vendor.airflow.providers.apache.hive.transfers',
 'airfly._vendor.airflow.providers.apache.pig',
 'airfly._vendor.airflow.providers.apache.pig.operators',
 'airfly._vendor.airflow.providers.apache.spark',
 'airfly._vendor.airflow.providers.apache.spark.operators',
 'airfly._vendor.airflow.providers.apache.sqoop',
 'airfly._vendor.airflow.providers.apache.sqoop.operators',
 'airfly._vendor.airflow.providers.celery',
 'airfly._vendor.airflow.providers.celery.sensors',
 'airfly._vendor.airflow.providers.cncf',
 'airfly._vendor.airflow.providers.cncf.kubernetes',
 'airfly._vendor.airflow.providers.cncf.kubernetes.operators',
 'airfly._vendor.airflow.providers.databricks',
 'airfly._vendor.airflow.providers.databricks.operators',
 'airfly._vendor.airflow.providers.datadog',
 'airfly._vendor.airflow.providers.datadog.sensors',
 'airfly._vendor.airflow.providers.dingding',
 'airfly._vendor.airflow.providers.dingding.operators',
 'airfly._vendor.airflow.providers.discord',
 'airfly._vendor.airflow.providers.discord.operators',
 'airfly._vendor.airflow.providers.docker',
 'airfly._vendor.airflow.providers.docker.operators',
 'airfly._vendor.airflow.providers.ftp',
 'airfly._vendor.airflow.providers.ftp.sensors',
 'airfly._vendor.airflow.providers.google',
 'airfly._vendor.airflow.providers.google.cloud',
 'airfly._vendor.airflow.providers.google.cloud.operators',
 'airfly._vendor.airflow.providers.google.cloud.sensors',
 'airfly._vendor.airflow.providers.google.cloud.transfers',
 'airfly._vendor.airflow.providers.google.suite',
 'airfly._vendor.airflow.providers.google.suite.transfers',
 'airfly._vendor.airflow.providers.grpc',
 'airfly._vendor.airflow.providers.grpc.operators',
 'airfly._vendor.airflow.providers.http',
 'airfly._vendor.airflow.providers.http.operators',
 'airfly._vendor.airflow.providers.http.sensors',
 'airfly._vendor.airflow.providers.imap',
 'airfly._vendor.airflow.providers.imap.sensors',
 'airfly._vendor.airflow.providers.jdbc',
 'airfly._vendor.airflow.providers.jdbc.operators',
 'airfly._vendor.airflow.providers.jenkins',
 'airfly._vendor.airflow.providers.jenkins.operators',
 'airfly._vendor.airflow.providers.jira',
 'airfly._vendor.airflow.providers.jira.operators',
 'airfly._vendor.airflow.providers.jira.sensors',
 'airfly._vendor.airflow.providers.microsoft',
 'airfly._vendor.airflow.providers.microsoft.azure',
 'airfly._vendor.airflow.providers.microsoft.azure.operators',
 'airfly._vendor.airflow.providers.microsoft.azure.sensors',
 'airfly._vendor.airflow.providers.microsoft.azure.transfers',
 'airfly._vendor.airflow.providers.microsoft.mssql',
 'airfly._vendor.airflow.providers.microsoft.mssql.operators',
 'airfly._vendor.airflow.providers.microsoft.winrm',
 'airfly._vendor.airflow.providers.microsoft.winrm.operators',
 'airfly._vendor.airflow.providers.mongo',
 'airfly._vendor.airflow.providers.mongo.sensors',
 'airfly._vendor.airflow.providers.mysql',
 'airfly._vendor.airflow.providers.mysql.operators',
 'airfly._vendor.airflow.providers.mysql.transfers',
 'airfly._vendor.airflow.providers.opsgenie',
 'airfly._vendor.airflow.providers.opsgenie.operators',
 'airfly._vendor.airflow.providers.oracle',
 'airfly._vendor.airflow.providers.oracle.operators',
 'airfly._vendor.airflow.providers.oracle.transfers',
 'airfly._vendor.airflow.providers.papermill',
 'airfly._vendor.airflow.providers.papermill.operators',
 'airfly._vendor.airflow.providers.postgres',
 'airfly._vendor.airflow.providers.postgres.operators',
 'airfly._vendor.airflow.providers.qubole',
 'airfly._vendor.airflow.providers.qubole.operators',
 'airfly._vendor.airflow.providers.qubole.sensors',
 'airfly._vendor.airflow.providers.redis',
 'airfly._vendor.airflow.providers.redis.operators',
 'airfly._vendor.airflow.providers.redis.sensors',
 'airfly._vendor.airflow.providers.segment',
 'airfly._vendor.airflow.providers.segment.operators',
 'airfly._vendor.airflow.providers.sftp',
 'airfly._vendor.airflow.providers.sftp.operators',
 'airfly._vendor.airflow.providers.sftp.sensors',
 'airfly._vendor.airflow.providers.slack',
 'airfly._vendor.airflow.providers.slack.operators',
 'airfly._vendor.airflow.providers.snowflake',
 'airfly._vendor.airflow.providers.snowflake.operators',
 'airfly._vendor.airflow.providers.sqlite',
 'airfly._vendor.airflow.providers.sqlite.operators',
 'airfly._vendor.airflow.providers.ssh',
 'airfly._vendor.airflow.providers.ssh.operators',
 'airfly._vendor.airflow.providers.vertica',
 'airfly._vendor.airflow.providers.vertica.operators',
 'airfly._vendor.airflow.sensors',
 'airfly._vendor.airflow.serialization',
 'airfly._vendor.airflow.utils',
 'airfly._vendor.airflow.utils.log',
 'airfly.cli',
 'airfly.model']

package_data = \
{'': ['*']}

install_requires = \
['astor>=0.8.1,<0.9.0',
 'attrs<21',
 'black>=21.7b0,<22.0',
 'cattrs<1.7.0',
 'click>=8.0.1,<9.0.0',
 'isort<5.9',
 'networkx>=2.6.2,<3.0.0',
 'regex>=2021.9.24,<2022.0.0']

entry_points = \
{'console_scripts': ['airfly = airfly.cli.main:main']}

setup_kwargs = {
    'name': 'airfly',
    'version': '0.6.1',
    'description': "Auto generate Airflow's dag.py on the fly",
    'long_description': '![](https://github.com/ryanchao2012/airfly/actions/workflows/airfly-run-unittests.yml/badge.svg)\n![](https://img.shields.io/pypi/v/airfly.svg)\n![](https://img.shields.io/pypi/pyversions/airfly)\n![](https://img.shields.io/github/license/ryanchao2012/airfly)\n\n\n# AirFly: Auto Generate Airflow\'s `dag.py` On The Fly\n\nPipeline management is essential for data operation in company, many engineering teams rely on tools like Airflow to help them organize workflows, such as ETL, data analytic jobs or machine learning projects.\n\nAirflow provides rich extensibility to let developers arrange workloads into a sequence of "operators", then they declare the task dependencies within a `DAG` context while writing the `dag.py` file. \n\nAs workflow grows progressively, the increasing complexity of task relations prones to messing up the dag structure, leads to decrease of code maintainability, especially in collaborative scenarios.\n\n`airfly` tries to mitigate such pain-points and brings automation to this development life cycle, it assumes all tasks are managed in certain python module, developers specify the dependencies while defining the task objects. During deployment, `airfly` can resolve the dependency tree and automatically build the `dag.py` for you.\n\n## Install\n\nDownload `airfly` from PyPi\n\n```\n$ pip install airfly\n\n$ airfly --help\nUsage: airfly [OPTIONS]\n\nOptions:\n  --version                   Show version and exit.\n  -n, --name TEXT             Assign to DAG id.\n  -m, --modname TEXT          Name of the module to search tasks for building\n                              the task dependency tree and using it to\n                              generate the airflow DAG file.\n  -p, --path TEXT             Insert into "sys.path" to include certain\n                              modules, multi-value is allowed.\n  -e, --exclude-pattern TEXT  Exclude the tasks from the dependency tree if\n                              their __qualname__ get matched with this regex\n                              pattern.\n  -i, --includes TEXT         Paths of python files, the codes within will be\n                              included in the output DAG file, multi-value is\n                              allowed.\n  -d, --dag-params TEXT       Parameters to construct DAG object, defined by a\n                              dictionary in a python file. Pass this option\n                              with <python-file>:<variable> form, the\n                              <variable> should be the dictionary which will\n                              be passed to DAG as keyword arguments.\n  --help                      Show this message and exit.\n\n```\n\n## Usage\n\n`airfly` expects the implementations are populated in a Python module(or package), the task dependencies are declared by assigning `upstreams` and `downstreams` attributes to each object. The task objects are actually wrappers for Airflow operators, when `airfly` walks through the entire module, all tasks are discovered and collected, the dependency tree and the `DAG` context are automatically built, with some `ast` helpers, `airfly` can wrap all these information, convert them into python code, and finally save them to `dag.py`.\n\n<img src="https://github.com/ryanchao2012/airfly/blob/main/assets/layout.png?raw=true" width="500">\n\n\n### Wrap Airflow operator with `AirflowTask`\n\nIn order to do codegen, collect the operator\'s metadata into a `AirflowTask` subclass as following(see [demo](https://github.com/ryanchao2012/airfly/blob/main/examples/tutorial/demo.py)):\n\n```python\n# in demo.py\nfrom airfly.model.airflow import AirflowTask\n\n\nclass print_date(AirflowTask):\n    operator_class = "BashOperator" \n    params = dict(bash_command="date")\n```\n\n* `operator_class` specifies the class of the Airflow operator.\n* The class name(`print_date`) will be mapped to `task_id` to the applied operator after code generation.\n* `params` will be passed to operator as keyword argument.\n\n\n### Declare task dependency\n\nUse `upstreams` and `downstreams` to specify task dependencies.\n\n```python\n# in demo.py\n\nfrom textwrap import dedent\n\n\ntemplated_command = dedent(\n    """\n{% for i in range(5) %}\n    echo "{{ ds }}"\n    echo "{{ macros.ds_add(ds, 7)}}"\n    echo "{{ params.my_param }}"\n{% endfor %}\n"""\n)\n\nclass templated(AirflowTask):\n    operator_class = "BashOperator"\n    params = dict(depends_on_past=False,\n                  bash_command=templated_command,\n                  params={"my_param": "Parameter I passed in"})\n\n\nclass sleep(AirflowTask):\n    operator_class = "BashOperator"\n    params = dict(depends_on_past=False, \n                  bash_command="sleep 5",\n                  retries=3)\n\n    upstreams = print_date\n    downstreams = (templated,)\n```\n\n\n### Generate the `dag.py` file\nWith commandline interface:\n```\n$ airfly --name demo_dag --modname demo > dag.py\n```\n\nThe outputs in `dag.py`:\n\n```python\n# This file is auto-generated by airfly 0.6.0\nfrom airflow.models import DAG\nfrom airflow.operators.bash import BashOperator\n\nwith DAG("demo_dag") as dag:\n    demo_print_date = BashOperator(task_id="demo.print_date", bash_command="date")\n    demo_sleep = BashOperator(\n        task_id="demo.sleep", depends_on_past=False, bash_command="sleep 5", retries=3\n    )\n    demo_templated = BashOperator(\n        task_id="demo.templated",\n        depends_on_past=False,\n        bash_command="""\n{% for i in range(5) %}\n    echo "{{ ds }}"\n    echo "{{ macros.ds_add(ds, 7)}}"\n    echo "{{ params.my_param }}"\n{% endfor %}\n""",\n        params={"my_param": "Parameter I passed in"},\n    )\n    demo_print_date >> demo_sleep\n    demo_sleep >> demo_templated\n```\n\n\n## Inject parameters to `DAG`\n\nIf any additional arguments are needed, write and manage those configurations in a python file(see [demo](https://github.com/ryanchao2012/airfly/blob/main/examples/tutorial/params.py)), `airfly` can pass them to `DAG` during codegen.\n\n```python\n# in params.py\n\nfrom datetime import timedelta\n\nfrom airflow.utils.dates import days_ago\n\ndefault_args = {\n    "owner": "airflow",\n    "depends_on_past": False,\n    "email": ["airflow@example.com"],\n    "email_on_failure": False,\n    "email_on_retry": False,\n    "retries": 1,\n    "retry_delay": timedelta(minutes=5),\n    # \'queue\': \'bash_queue\',\n    # \'pool\': \'backfill\',\n    # \'priority_weight\': 10,\n    # \'end_date\': datetime(2016, 1, 1),\n    # \'wait_for_downstream\': False,\n    # \'dag\': dag,\n    # \'sla\': timedelta(hours=2),\n    # \'execution_timeout\': timedelta(seconds=300),\n    # \'on_failure_callback\': some_function,\n    # \'on_success_callback\': some_other_function,\n    # \'on_retry_callback\': another_function,\n    # \'sla_miss_callback\': yet_another_function,\n    # \'trigger_rule\': \'all_success\'\n}\n\ndag_kwargs = dict(\n    default_args=default_args,\n    description="A simple tutorial DAG",\n    schedule_interval=timedelta(days=1),\n    start_date=days_ago(2),\n    tags=["example"],\n)\n```\n\nInject those arguments with `--dag-params` option:\n```\n$ airfly --name demo_dag --modname demo --dag-params params.py:dag_kwargs > dag.py\n```\n\nThe outputs in `dag.py`:\n```python\n# This file is auto-generated by airfly 0.6.0\nfrom datetime import timedelta\n\nfrom airflow.models import DAG\nfrom airflow.operators.bash import BashOperator\nfrom airflow.utils.dates import days_ago\n\n# >>>>>>>>>> Include from \'params.py\'\ndefault_args = {\n    "owner": "airflow",\n    "depends_on_past": False,\n    "email": ["airflow@example.com"],\n    "email_on_failure": False,\n    "email_on_retry": False,\n    "retries": 1,\n    "retry_delay": timedelta(minutes=5),\n}\ndag_kwargs = dict(\n    default_args=default_args,\n    description="A simple tutorial DAG",\n    schedule_interval=timedelta(days=1),\n    start_date=days_ago(2),\n    tags=["example"],\n)\n# <<<<<<<<<< End of code insertion\nwith DAG("demo_dag", **dag_kwargs) as dag:\n    demo_print_date = BashOperator(task_id="demo.print_date", bash_command="date")\n    demo_sleep = BashOperator(\n        task_id="demo.sleep", depends_on_past=False, bash_command="sleep 5", retries=3\n    )\n    demo_templated = BashOperator(\n        task_id="demo.templated",\n        depends_on_past=False,\n        bash_command="""\n{% for i in range(5) %}\n    echo "{{ ds }}"\n    echo "{{ macros.ds_add(ds, 7)}}"\n    echo "{{ params.my_param }}"\n{% endfor %}\n""",\n        params={"my_param": "Parameter I passed in"},\n    )\n    demo_print_date >> demo_sleep\n    demo_sleep >> demo_templated\n```\n\n`airfly` wraps required information including variables and imports into output python script, and pass the specified value to `DAG` object.\n\n\n## Exclude tasks from codegen\nBy passing `--exclude-pattern` to match any unwanted objects with their `__qualname__`. then filter them out.\n```\n$ airfly --name demo_dag --modname demo --exclude-pattern templated > dag.py\n```\n\nThe outputs in `dag.py`:\n\n```python\n# This file is auto-generated by airfly 0.6.0\nfrom airflow.models import DAG\nfrom airflow.operators.bash import BashOperator\n\nwith DAG("demo_dag") as dag:\n    demo_print_date = BashOperator(task_id="demo.print_date", bash_command="date")\n    demo_sleep = BashOperator(\n        task_id="demo.sleep", depends_on_past=False, bash_command="sleep 5", retries=3\n    )\n    demo_print_date >> demo_sleep\n```\n\nThe `templated` task is gone.\n\n\n## Examples\n\nPlease visit [examples](https://github.com/ryanchao2012/airfly/blob/main/examples) to explore more use cases.\n<a href="https://github.com/ryanchao2012/airfly/blob/main/examples"><img src="https://github.com/ryanchao2012/airfly/blob/main/assets/view.png?raw=true" width="500"></img></a>',
    'author': 'ryanchao2012',
    'author_email': 'ryanchao2012@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ryanchao2012/airfly',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.mysql_to_gcs import (
    MySQLToGCSOperator,
)


class MySqlToGoogleCloudStorageOperator(MySQLToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class FTPSensor(BaseSensorOperator):
    path: "str"
    ftp_conn_id: "str"
    fail_on_transient_errors: "bool"


class FTPSSensor(FTPSensor):
    path: "str"
    ftp_conn_id: "str"
    fail_on_transient_errors: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.vertica_to_hive import (
    VerticaToHiveOperator,
)


class VerticaToHiveTransfer(VerticaToHiveOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SqliteOperator(BaseOperator):
    sql: "str"
    sqlite_conn_id: "str"
    parameters: "typing.Union[typing.Mapping, typing.Iterable, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.mssql_to_gcs import (
    MSSQLToGCSOperator,
)


class MsSqlToGoogleCloudStorageOperator(MSSQLToGCSOperator):
    pass



# NOTE: This file is auto-generated by "inv sync-meta"

name = "airfly"
version = "0.6.1"
description = "Auto generate Airflow's dag.py on the fly"
authors = ["ryanchao2012 <ryanchao2012@gmail.com>"]
license = "MIT"
readme = "README.md"
repository = "https://github.com/ryanchao2012/airfly"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PubSubCreateSubscriptionOperator(BaseOperator):
    topic: "str"
    project_id: "typing.Union[str, NoneType]"
    subscription: "typing.Union[str, NoneType]"
    subscription_project_id: "typing.Union[str, NoneType]"
    ack_deadline_secs: "int"
    fail_if_exists: "bool"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    push_config: "typing.Union[typing.Dict, google.cloud.pubsub_v1.types.PushConfig, NoneType]"
    retain_acked_messages: "typing.Union[bool, NoneType]"
    message_retention_duration: "typing.Union[typing.Dict, google.protobuf.duration_pb2.Duration, NoneType]"
    labels: "typing.Union[typing.Dict[str, str], NoneType]"
    enable_message_ordering: "bool"
    expiration_policy: "typing.Union[typing.Dict, google.cloud.pubsub_v1.types.ExpirationPolicy, NoneType]"
    filter_: "typing.Union[str, NoneType]"
    dead_letter_policy: "typing.Union[typing.Dict, google.cloud.pubsub_v1.types.DeadLetterPolicy, NoneType]"
    retry_policy: "typing.Union[typing.Dict, google.cloud.pubsub_v1.types.RetryPolicy, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    topic_project: "typing.Union[str, NoneType]"
    subscription_project: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class PubSubCreateTopicOperator(BaseOperator):
    topic: "str"
    project_id: "typing.Union[str, NoneType]"
    fail_if_exists: "bool"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict[str, str], NoneType]"
    message_storage_policy: "typing.Union[typing.Dict, google.cloud.pubsub_v1.types.MessageStoragePolicy]"
    kms_key_name: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    project: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class PubSubDeleteSubscriptionOperator(BaseOperator):
    subscription: "str"
    project_id: "typing.Union[str, NoneType]"
    fail_if_not_exists: "bool"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    project: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class PubSubDeleteTopicOperator(BaseOperator):
    topic: "str"
    project_id: "typing.Union[str, NoneType]"
    fail_if_not_exists: "bool"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    project: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class PubSubPublishMessageOperator(BaseOperator):
    topic: "str"
    messages: "typing.List"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    project: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



import os

import click
from airfly.model.airflow import AirflowDAG, AirflowTask
from airfly.model.base import TaskTree, collect_taskpairs, collect_taskset
from airfly.utils import load_module_by_name

from .utils import (
    InvalidModule,
    convert_dag_params,
    expand_sys_path,
    print_version,
    should_exclude,
    validate_includes,
)


@click.command()
@click.option(
    "--version",
    is_flag=True,
    callback=print_version,
    expose_value=False,
    is_eager=True,
    help="Show version and exit.",
)
@click.option("--name", "-n", help="Assign to DAG id.")
@click.option(
    "--modname",
    "-m",
    help=(
        "Name of the module to search tasks"
        " for building the task dependency tree"
        " and using it to generate the airflow DAG file."
    ),
)
@click.option(
    "--path",
    "-p",
    multiple=True,
    default=[os.getcwd()],
    help='Insert into "sys.path" to include certain modules, multi-value is allowed.',
)
@click.option(
    "--exclude-pattern",
    "-e",
    help=(
        "Exclude the tasks from the dependency tree"
        " if their __qualname__ get matched with this regex pattern."
    ),
)
@click.option(
    "--includes",
    "-i",
    callback=validate_includes,
    help=(
        "Paths of python files, the codes within"
        " will be included in the output DAG file, multi-value is allowed."
    ),
    multiple=True,
)
@click.option(
    "--dag-params",
    "-d",
    callback=convert_dag_params,
    help=(
        "Parameters to construct DAG object,"
        " defined by a dictionary in a python file."
        " Pass this option with <python-file>:<variable> form,"
        " the <variable> should be the dictionary"
        " which will be passed to DAG as keyword arguments."
    ),
)
def main(name, modname, path, exclude_pattern, includes, dag_params):

    with expand_sys_path(*path):
        try:
            module = load_module_by_name(modname)
        except Exception:
            raise InvalidModule(f'got: "{modname}"')

    name = name or f"{modname}_dag"

    if dag_params[0]:
        if includes:
            includes.append(dag_params[0])
        else:
            includes = [dag_params[0]]

    taskset = set(
        collect_taskset(
            module,
            taskclass=AirflowTask,
            predicate=lambda obj: not should_exclude(obj, exclude_pattern),
        )
    )

    taskpairs = set(
        collect_taskpairs(
            taskset,
            taskclass=AirflowTask,
            predicate=lambda pair: not (
                should_exclude(pair.up, exclude_pattern, verbose=False)
                or should_exclude(pair.down, exclude_pattern, verbose=False)
            ),
        )
    )
    tasktree = TaskTree(taskset=taskset, taskpairs=taskpairs)

    dag = AirflowDAG(name, tasktree, includes=includes, dag_params=dag_params)

    print(dag.render())



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SnowflakeOperator(BaseOperator):
    sql: "typing.Any"
    snowflake_conn_id: "str"
    parameters: "typing.Union[dict, NoneType]"
    autocommit: "bool"
    warehouse: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"
    role: "typing.Union[str, NoneType]"
    schema: "typing.Union[str, NoneType]"
    authenticator: "typing.Union[str, NoneType]"
    session_parameters: "typing.Union[dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DatadogSensor(BaseSensorOperator):
    datadog_conn_id: "str"
    from_seconds_ago: "int"
    up_to_seconds_from_now: "int"
    priority: "typing.Union[str, NoneType]"
    sources: "typing.Union[str, NoneType]"
    tags: "typing.Union[typing.List[str], NoneType]"
    response_check: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], bool], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudDataTransferServiceCancelOperationOperator(BaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServiceCreateJobOperator(BaseOperator):
    body: "dict"
    aws_conn_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServiceDeleteJobOperator(BaseOperator):
    job_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    project_id: "typing.Union[str, NoneType]"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
    source_bucket: "str"
    destination_bucket: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    description: "typing.Union[str, NoneType]"
    schedule: "typing.Union[typing.Dict, NoneType]"
    object_conditions: "typing.Union[typing.Dict, NoneType]"
    transfer_options: "typing.Union[typing.Dict, NoneType]"
    wait: "bool"
    timeout: "typing.Union[float, NoneType]"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    delete_job_after_completion: "bool"


class CloudDataTransferServiceGetOperationOperator(BaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServiceListOperationsOperator(BaseOperator):
    request_filter: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServicePauseOperationOperator(BaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServiceResumeOperationOperator(BaseOperator):
    operation_name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
    s3_bucket: "str"
    gcs_bucket: "str"
    project_id: "typing.Union[str, NoneType]"
    aws_conn_id: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    description: "typing.Union[str, NoneType]"
    schedule: "typing.Union[typing.Dict, NoneType]"
    object_conditions: "typing.Union[typing.Dict, NoneType]"
    transfer_options: "typing.Union[typing.Dict, NoneType]"
    wait: "bool"
    timeout: "typing.Union[float, NoneType]"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    delete_job_after_completion: "bool"


class CloudDataTransferServiceUpdateJobOperator(BaseOperator):
    job_name: "str"
    body: "dict"
    aws_conn_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DateTimeSensor(BaseSensorOperator):
    target_time: "typing.Union[str, datetime.datetime]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.bigtable import (
    BigtableCreateInstanceOperator,
    BigtableCreateTableOperator,
    BigtableDeleteInstanceOperator,
    BigtableDeleteTableOperator,
    BigtableUpdateClusterOperator,
)
from airfly._vendor.airflow.providers.google.cloud.sensors.bigtable import (
    BigtableTableReplicationCompletedSensor,
)


class BigtableClusterUpdateOperator(BigtableUpdateClusterOperator):
    pass


class BigtableInstanceCreateOperator(BigtableCreateInstanceOperator):
    pass


class BigtableInstanceDeleteOperator(BigtableDeleteInstanceOperator):
    pass


class BigtableTableCreateOperator(BigtableCreateTableOperator):
    pass


class BigtableTableDeleteOperator(BigtableDeleteTableOperator):
    pass


class BigtableTableWaitForReplicationSensor(BigtableTableReplicationCompletedSensor):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SFTPOperator(BaseOperator):
    ssh_hook: "_empty"
    ssh_conn_id: "_empty"
    remote_host: "_empty"
    local_filepath: "_empty"
    remote_filepath: "_empty"
    operation: "_empty"
    confirm: "_empty"
    create_intermediate_dirs: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.spanner import (
    SpannerDeleteDatabaseInstanceOperator,
    SpannerDeleteInstanceOperator,
    SpannerDeployDatabaseInstanceOperator,
    SpannerDeployInstanceOperator,
    SpannerQueryDatabaseInstanceOperator,
    SpannerUpdateDatabaseInstanceOperator,
)


class CloudSpannerInstanceDatabaseDeleteOperator(SpannerDeleteDatabaseInstanceOperator):
    pass


class CloudSpannerInstanceDatabaseDeployOperator(SpannerDeployDatabaseInstanceOperator):
    pass


class CloudSpannerInstanceDatabaseQueryOperator(SpannerQueryDatabaseInstanceOperator):
    pass


class CloudSpannerInstanceDatabaseUpdateOperator(SpannerUpdateDatabaseInstanceOperator):
    pass


class CloudSpannerInstanceDeleteOperator(SpannerDeleteInstanceOperator):
    pass


class CloudSpannerInstanceDeployOperator(SpannerDeployInstanceOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class VerticaToHiveOperator(BaseOperator):
    sql: "_empty"
    hive_table: "_empty"
    create: "_empty"
    recreate: "_empty"
    partition: "_empty"
    delimiter: "_empty"
    vertica_conn_id: "_empty"
    hive_cli_conn_id: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class RedshiftToS3Operator(BaseOperator):
    s3_bucket: "str"
    s3_key: "str"
    schema: "str"
    table: "str"
    select_query: "str"
    redshift_conn_id: "str"
    aws_conn_id: "str"
    verify: "typing.Union[bool, str, NoneType]"
    unload_options: "typing.Union[typing.List, NoneType]"
    autocommit: "bool"
    include_header: "bool"
    table_as_file_name: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.gcs_to_gcs import (
    GCSToGCSOperator,
)


class GoogleCloudStorageToGoogleCloudStorageOperator(GCSToGCSOperator):
    pass



from types import ModuleType
from typing import Generator, List, Sequence, Set, Tuple, Type, Union

import attr
import networkx as nx
from airfly._ast import immutable
from airfly.utils import collect_objects

TaskClass = Type["BaseTask"]


class BaseTask:
    upstreams: Union[Tuple[TaskClass, ...], TaskClass] = None
    downstreams: Union[Tuple[TaskClass, ...], TaskClass] = None


@immutable
class TaskPair:
    up: TaskClass
    down: TaskClass


@immutable
class TaskTree:

    taskset: Set[BaseTask]
    taskpairs: Set[TaskPair]

    _dag: nx.DiGraph = attr.ib(init=False)

    @_dag.default
    def _create_dag(self):
        dag = nx.DiGraph()
        dag.add_nodes_from(self.taskset)
        dag.add_edges_from((pair.up, pair.down) for pair in self.taskpairs)

        return dag

    @property
    def roots(self) -> List[TaskClass]:
        return [node for node in self._dag.nodes() if self._dag.in_degree(node) == 0]

    @property
    def leaves(self) -> List[TaskClass]:
        return [node for node in self._dag.nodes() if self._dag.out_degree(node) == 0]

    @property
    def nodes(self) -> Sequence[TaskClass]:
        return self._dag.nodes

    @property
    def edges(self) -> Sequence[Tuple[TaskClass, TaskClass]]:
        return self._dag.edges


def collect_taskset(
    module: ModuleType, taskclass: TaskClass = BaseTask, predicate=lambda _: True
) -> Generator[TaskClass, None, None]:

    for cls in collect_objects(
        module,
        predicate=lambda obj: isinstance(obj, type)
        and issubclass(obj, taskclass)
        and predicate(obj),
    ):

        yield cls  # return task class with no duplication


def collect_taskpairs(
    taskset: Set[TaskClass], taskclass: TaskClass = BaseTask, predicate=lambda _: True
) -> Generator[TaskPair, None, None]:

    cached = set()

    for cls in taskset:

        ups = cls.upstreams  # could be None, Task or Tuple[Task, ...]

        if isinstance(ups, type) and issubclass(ups, taskclass):
            ups = [ups]

        for u in ups or []:

            pair = TaskPair(up=u, down=cls)

            if pair not in cached and predicate(pair):

                cached.add(pair)

                yield pair

        downs = cls.downstreams  # could be None, Task or Tuple[Task, ...]

        if isinstance(downs, type) and issubclass(downs, taskclass):
            downs = [downs]

        for d in downs or []:

            pair = TaskPair(up=cls, down=d)

            if pair not in cached and predicate(pair):

                cached.add(pair)

                yield pair


class Workflow:
    def to_source(self) -> str:
        raise NotImplementedError

    def to_file(self, path: str):
        pass
